require 'minitest/autorun'
require_relative '../lib/roman_numeral_generator'

class TestGenerator < MiniTest::Unit::TestCase
  describe "generate" do
    def setup
      @generator = RomanNumeralGenerator.new
    end

    describe "when number is out of range" do
      it "raises an exception" do
        assert_raises(RangeError) { @generator.generate(0) }
        assert_raises(RangeError) { @generator.generate(4000) }
      end
    end

    describe "when number is valid" do
      it "generates the right Roman number" do
        assert_equal @generator.generate(1), "I"
        assert_equal @generator.generate(5), "V"
        assert_equal @generator.generate(10), "X"
        assert_equal @generator.generate(20), "XX"
        assert_equal @generator.generate(3999), "MMMCMXCIX"
      end
    end
  end

  describe "is_out_of_range" do
    def setup
      @generator = RomanNumeralGenerator.new
    end

    describe "when number is inside range" do
      it "is false" do
        assert !@generator.is_out_of_range?(100), "is false"
      end
    end

    describe "when number is lower than 1" do
      it "is true" do
        assert @generator.is_out_of_range?(0), "is true"
      end
    end

    describe "when number is greater than 3999" do
      it "is true" do
        assert @generator.is_out_of_range?(4000), "is true"
      end
    end
  end
end
